@@ -1,23 +1,11 @@
 /*
- *   Copyright (C) 2019 Méven Car (meven.car@kdemail.net)
+ *   SPDX-FileCopyrightText: 2019 Méven Car (meven.car@kdemail.net)
  *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "GtkEventSpy.h"
 
-#include <QStringList>
 #include <QString>
 #include <QUrl>
 #include <QFileInfo>
